##  Configuring Template Fields
When creating or configuring the template, clicking on a template field opens a side panel where you can modify the template's fields. Changes made in the side panel are reflected in real-time, allowing you to preview how the template will appear to other users.
You can modify field labels to provide clear context for the users and also rearrange the order of the fields as needed.
![Using Side Panel for Configuring Transformation Template](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f59347a441014aaf5f0049823a91f_LowRes.gif)
Configuring Template Fields in the Side Panel
